package com.miaxis.framework.web.service;

import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.core.domain.entity.UserInfo;
import com.miaxis.common.core.domain.model.LoginUser;
import com.miaxis.common.enums.StudentLoginTypeEnum;
import com.miaxis.common.enums.UserStatusEnum;
import com.miaxis.common.exception.BaseException;
import com.miaxis.common.exception.CustomException;
import com.miaxis.common.utils.RandomNameUtils;
import com.miaxis.common.utils.ServletUtils;
import com.miaxis.common.utils.StringUtils;
import com.miaxis.system.service.ISysUserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

/**
 * 用户验证处理
 *
 * @author miaxis
 */
@Service
public class UserDetailsServiceImpl implements UserDetailsService
{
    private static final Logger log = LoggerFactory.getLogger(UserDetailsServiceImpl.class);

    @Autowired
    private ISysUserService userService;


    @Autowired
    private SysPermissionService permissionService;

    @Override
    public UserDetails loadUserByUsername(String identification) throws UsernameNotFoundException {
        //获取登录类型
        String loginType = (String) ServletUtils.getRequest().getAttribute("loginType");
        if (StringUtils.isEmpty(loginType)){
            SysUser user = userService.selectUserByUserName(identification);
            if (StringUtils.isNull(user))
            {
                log.info("登录用户：{} 不存在.", identification);
                throw new UsernameNotFoundException("登录用户：" + identification + " 不存在");
            }
            else if (UserStatusEnum.DELETED.getCode().equals(user.getDelFlag()))
            {
                log.info("登录用户：{} 已被删除.", identification);
                throw new BaseException("对不起，您的账号：" + identification + " 已被删除");
            }
            else if (UserStatusEnum.DISABLE.getCode().equals(user.getStatus()))
            {
                log.info("登录用户：{} 已被停用.", identification);
                throw new BaseException("对不起，您的账号：" + identification + " 已停用");
            }
            return createLoginUser(user);
        } else if (StudentLoginTypeEnum.OPENID_LOGIN.getCode().equals(loginType)){
            {
                UserInfo userInfo = userService.getStudentByOpenId(identification);
                if (userInfo == null) {
                    userInfo.setHeadImage("http://image.jppt.com.cn/zzjs/2021-03-10/others/1615365365814.png");
                    userInfo.setNickName(RandomNameUtils.generateName());
                    userInfo.setOpenid(identification);
                    userService.saveUserInfo(userInfo);
                }
                return createLoginUser(userInfo);
            }
        } else{
            throw new CustomException("登录类型不存在");
        }



    }

    private UserDetails createLoginUser(UserInfo student) {
        return new LoginUser(student);
    }

    public UserDetails createLoginUser(SysUser user)
    {
        return new LoginUser(user, permissionService.getMenuPermission(user));
    }
}
